@@ -172,14 +172,15 @@ def process_video(video_path, opt):
     raw_height = meta_data["height"]
     cropped_height = raw_height
     if "top" in opt.crop_mode:
-        cropped_height = int(raw_height * (1 - (opt.crop_percent / 100)))  # crop x% of the video from the top
+        cropped_height = int(raw_height * (1 - (opt.crop_percent / 100)))  # x% of the video from the top
     cropped_width = raw_width
     if "left" and "right" in opt.crop_mode:
-        cropped_width = int(raw_width * (1 - (2*opt.crop_percent / 100)))  # crop x% of the video from the top
+        cropped_width = int(raw_width * (1 - (2*opt.crop_percent / 100)))  # x% of the video from both left/right
     elif "left" in opt.crop_mode or "right" in opt.crop_mode:
-        cropped_width = int(raw_width * (1 - (opt.crop_percent / 100)))
+        cropped_width = int(raw_width * (1 - (opt.crop_percent / 100)))  # x% of the video from both left/right
     resolution = (int(cropped_width), int(cropped_height))
     h_start_at = (raw_height - cropped_height)
+    h_end_at = raw_height
     if "left" and "right" in opt.crop_mode:
         w_start_at = (raw_width - cropped_width)//2
         w_end_at = w_start_at + cropped_width
@@ -192,22 +193,31 @@ def process_video(video_path, opt):
     elif "top" in opt.crop_mode:
         w_start_at = 0
         w_end_at = raw_width
-    return cap, framerate, resolution, h_start_at, w_start_at, w_end_at
+    return cap, framerate, resolution, h_start_at, h_end_at, w_start_at, w_end_at
 
 def load_models(opt):
     """
     loads all relevant neural network models to perform predictions
-    models will be automatically downloaded if not found in the cache, user may overide downloaded location wit hthe env variable ICATCHER_DATA_DIR
+    models will be automatically downloaded if not found in the cache,
+    user may overide downloaded location with the env variable ICATCHER_DATA_DIR
+    defaults:
+    :Mac: "~/Library/Caches/<AppName>"
+    :Unix: "~/.cache/<AppName>" or the value of the "XDG_CACHE_HOME"
+    environment variable, if defined.
+    :Windows: "C:\\Users\\<user>\\AppData\\Local\\<AppAuthor>\\<AppName>\\Cache"
     :param opt: command line options
     :return all nn models
     """
     GOODBOY = pooch.create(path=pooch.os_cache("icatcher_plus"),
-                           base_url="https://www.cs.tau.ac.il/~yotamerel/icatcher+/",
+                           base_url="https://osf.io/ycju8/download",
                            version=version,
                            version_dev="main",
                            env="ICATCHER_DATA_DIR",
-                           registry={"icatcher+_models.zip": "d78385b3a08f3d55ce75249142d15549e4c5552d5e1231cad3b69063bb778ce9"})
-    file_paths = GOODBOY.fetch("icatcher+_models.zip", processor=pooch.Unzip())
+                           registry={"icatcher+_models.zip": "d78385b3a08f3d55ce75249142d15549e4c5552d5e1231cad3b69063bb778ce9"},
+                           urls={"icatcher+_models.zip":"https://osf.io/ycju8/download"})
+    file_paths = GOODBOY.fetch("icatcher+_models.zip",
+                               processor=pooch.Unzip(),
+                               progressbar=True)
     file_names = [Path(x).name for x in file_paths]
     face_detector_model_file = file_paths[file_names.index("face_model.caffemodel")]
     config_file = file_paths[file_names.index("config.prototxt")]
@@ -269,7 +279,7 @@ def get_video_paths(opt):
         elif video_path.is_file():
             video_paths = [str(video_path)]
         else:
-            raise FileNotFoundError
+            raise FileNotFoundError("Couldn't find a file or a directory at {}".format(video_path))
     else:
         # video_paths = [int(opt.source)]
         raise NotImplementedError
@@ -343,7 +353,7 @@ def predict_from_video(opt):
     for i in range(len(video_paths)):
         video_path = Path(str(video_paths[i]))
         logging.info("predicting on : {}".format(video_path))
-        cap, framerate, resolution, h_start_at, w_start_at, w_end_at = process_video(video_path, opt)
+        cap, framerate, resolution, h_start_at, h_end_at, w_start_at, w_end_at = process_video(video_path, opt)
         video_output_file, prediction_output_file, skip = create_output_streams(video_path, framerate, resolution, opt)
         if skip:
             continue
@@ -363,7 +373,8 @@ def predict_from_video(opt):
         # loop over frames (refactor !)
         ret_val, frame = cap.read()
         while ret_val:
-            frame = frame[h_start_at:, w_start_at:w_end_at, :]  # crop x% of the video from the top
+            frame = draw.mask_regions(frame, h_start_at, h_end_at, w_start_at, w_end_at)  # mask roi
+            # frame = frame[h_start_at:, w_start_at:w_end_at, :]  # crop x% of the video from the top
             frames.append(frame)
             cv2_bboxes = detect_face_opencv_dnn(face_detector_model, frame, 0.7)
             frame = cv2.cvtColor(frame, cv2.COLOR_BGR2RGB)  # network was trained on RGB images.
